@@ -2,17 +2,15 @@
 #' @param map A leaflet map object
 #' @param path_to_img A path to the image file to save
 #' @param overwrite Do you want to clobber any existing file?
-#' @param vwidth see \code{\link[webshot2]{webshot}}
-#' @param vheight see \code{\link[webshot2]{webshot}}
-#' @param cliprect see \code{\link[webshot2]{webshot}}
-#' @param ... arguments passed to \code{\link[webshot2]{webshot}}
+#' @inheritParams webshot2::webshot
+#' @param ... arguments passed to [webshot2::webshot()]
 #' @export
 #' @return a path to a PNG file
 #' @examples 
 #' \dontrun{
 #' if (require(leaflet)) {
-#'   map <- leaflet() %>%
-#'     addTiles() %>%
+#'   map <- leaflet() |>
+#'     addTiles() |>
 #'     addMarkers(lng = 174.768, lat = -36.852, popup = "The birthplace of R")
 #'   save_webshot(map, tempfile())
 #' }
@@ -27,22 +25,19 @@ save_webshot <- function(map, path_to_img, overwrite = FALSE,
     out <- fs::path_ext_set(out, ".png")
   }
   
-  if (fs::file_exists(out)) {
-    warning("file exists already")  
+  if (fs::file_exists(out) & !overwrite) {
+    stop("file exists already")  
   }
   tmp_file <- fs::file_temp(ext = ".html")
-  map %>%
+  map |>
     htmlwidgets::saveWidget(
       file = tmp_file, 
       selfcontained = FALSE
     )
-  suppressWarnings(
-    # https://github.com/wch/webshot/issues/101
     webshot2::webshot(
       tmp_file, 
       file = out, 
       vwidth = vwidth, vheight = vheight, cliprect = cliprect, ...
     )
-  )
   return(out)
-}
\ No newline at end of file
+}
